==> pipewire-docs-1%3A0.3.43-5-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Overview", "page_overview.html", null ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"globals_defs_p.html",
"globals_l.html",
"group__pw__core.html#ga02ca8080671bb34a7f015eae9893bd9f",
"group__pw__impl__metadata.html#ga74106d1ae2eb30cee3b07a09d5e04b9d",
"group__pw__log.html#ga3c2e22a8450c053fd61cc974613952d1",
"group__pw__properties.html",
"group__pw__session__manager.html#gabf6a98119e15ceadfe6a59113d7b02ed",
"group__spa__ansi.html#gafddf179b8a30fe15781f37221f450901",
"group__spa__device.html#ggac7701f46169fcc7a70be0f7167b97cffa53397e3b7eb932bb53d11a9a56d63ba9",
"group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2",
"group__spa__node.html#gga89c01db6072aa9fd9ca5ac4dee9b6716ad26051f31e62903ba07f33db72a3941e",
"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a5415212a919922d9c78af124ad709a84",
"group__spa__param.html#gga6fa558a42ebf277d0fe21e1bee5c1218a44471947762ce745cc20fe6a1b959d73",
"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea2e0fc72c9a33b3367c75d8896ee469e4",
"group__spa__pod.html#ga8fe7f96447b154a8b0d3de31dba55adc",
"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a58faecf8df50f261bbc3a8e28b85b794",
"page_spa_pod.html",
"structpw__endpoint__stream__info.html#ae2e6491fda9eacf17fb4bf05caf5fe06",
"structpw__port__methods.html#a902dc57cb5eaae752960a0667ff10ab8",
"structspa__device__events.html#a64cea4459b8c4a483d0a2dd684f3e132",
"structspa__meta__busy.html",
"structspa__system__methods.html#adfaee480ca6869161824c85928c0e3d0"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pipewire-docs-1%3A0.3.44-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Overview", "page_overview.html", null ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"globals_defs_p.html",
"globals_l.html",
"group__pw__core.html#ga02ca8080671bb34a7f015eae9893bd9f",
"group__pw__impl__metadata.html#ga74106d1ae2eb30cee3b07a09d5e04b9d",
"group__pw__log.html#ga1d916620185fd923b3ec566bab209164",
"group__pw__profiler.html#gadce3d202b44c713a464705f5d1651231",
"group__pw__session__manager.html#gabe0075fd89732e5f50c189456cb9e7cd",
"group__spa__ansi.html#gaf63c55041d8c8bd7b319645c7f58a9d4",
"group__spa__device.html#gaee6259c06260e89b9c7e6186b9975998",
"group__spa__log.html#gab60b078a5687f091f11d951899e7c270",
"group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba938768f7da496bf7d953372b247d5030",
"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a1f7553ca6dfbb69fd33ed770e47081c0",
"group__spa__param.html#gga62e2ecfa3912b3c3ef09e818db457e65a02ccc301e9cddd49e61dc8a0cef2362b",
"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea107b70d9ca312a61fa29c3daecc91cb8",
"group__spa__pod.html#ga881cb54fc6b73cc389ce7f43e84ecd26",
"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a39b08d57355f457b217ab61fdf6fbbb2",
"page_spa_buffer.html",
"structpw__endpoint__link__methods.html#ac85085528468519f49c7bba87a12f2cd",
"structpw__node__methods.html#a66986c115ef6b4046c22774ea438a3ad",
"structspa__dbus.html",
"structspa__loop__utils__methods.html#a4466703d3ee6e18abc89bafea2b0c0ed",
"structspa__system__methods.html#a13bacd57bc170f5a2342ca95de203ee2"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
